using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.Data;
using System.Configuration;
using System.Web.Security;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Telerik.Web.UI;
using System.Collections;
using System.Collections.Generic;
using System.Web.UI.HtmlControls;
using System.Data.SqlClient;
using System.Text;

public partial class Default : System.Web.UI.Page
{
	private int _userID = 2;
	private SqlConnection _conn = new SqlConnection(ConfigurationManager.ConnectionStrings["DockConnectionString"].ConnectionString);
	private bool _dockStateCleared = false;

	private List<DockState> CurrentDockStates
	{
		get
		{
			//Get saved state string from the database - set it to dockState variable for example 
			string dockStatesFromDB = "";

			_conn.Open();
			SqlCommand command = new SqlCommand("select State from States where id='" + _userID + "' ", _conn);
			dockStatesFromDB = command.ExecuteScalar().ToString();
			_conn.Close();

			List<DockState> _currentDockStates = new List<DockState>();
			string[] stringStates = dockStatesFromDB.Split('|');
			foreach (string stringState in stringStates)
			{
				if (stringState.Trim() != string.Empty)
				{
					_currentDockStates.Add(DockState.Deserialize(stringState));
				}
			}
			return _currentDockStates;
		}
	}

	protected void Page_Load(object sender, EventArgs e)
	{
		if (!IsPostBack)
		{
			DropDownZone.DataBind();
		}
	}

	public ArrayList GetZones()
	{
		ArrayList zones = new ArrayList();
		zones.Add(RadDockZone1);
		zones.Add(RadDockZone2);
		zones.Add(RadDockZone3);
		return zones;
	}

	protected void Page_Init(object sender, EventArgs e)
	{
		//Recreate the docks in order to ensure their proper operation
		for (int i = 0; i < CurrentDockStates.Count; i++)
		{
			if (CurrentDockStates[i].Closed == false)
			{
				RadDock dock = CreateRadDockFromState(CurrentDockStates[i]);
				//We will just add the RadDock control to the RadDockLayout.
				// You could use any other control for that purpose, just ensure
				// that it is inside the RadDockLayout control.
				// The RadDockLayout control will automatically move the RadDock
				// controls to their corresponding zone in the LoadDockLayout
				// event (see below).
				RadDockLayout1.Controls.Add(dock);
				//We want to save the dock state every time a dock is moved.
				CreateSaveStateTrigger(dock);
				//Load the selected widget
				LoadWidget(dock);
			}
		}
	}

	protected void RadDockLayout1_LoadDockLayout(object sender, DockLayoutEventArgs e)
	{
		//Populate the event args with the state information. The RadDockLayout control
		// will automatically move the docks according that information.
		foreach (DockState state in CurrentDockStates)
		{
			e.Positions[state.UniqueName] = state.DockZoneID;
			e.Indices[state.UniqueName] = state.Index;
		}
	}

	protected void RadDockLayout1_SaveDockLayout(object sender, DockLayoutEventArgs e)
	{
		if (!_dockStateCleared)
		{
			//Save the dock state in the session. This will enable us
			// to recreate the dock in the next Page_Init.
			List<DockState> stateList = RadDockLayout1.GetRegisteredDocksState();
			StringBuilder serializedList = new StringBuilder();
			int i = 0;

			while (i < stateList.Count)
			{
				serializedList.Append(stateList[i].ToString());
				serializedList.Append("|");
				i++;
			}

			string dockState = serializedList.ToString();
			if (dockState.Trim() != String.Empty)
			{
				_conn.Open();
				SqlCommand command = new SqlCommand(String.Format("update States set State='{0}' where id='" + _userID + "'", dockState), _conn);
				command.ExecuteNonQuery();
				_conn.Close();
			}
		}
		else
		{
			//the clear state button was clicked, so we refresh the page and start over.
			Response.Redirect(Request.RawUrl, false);
		}
	}

	private RadDock CreateRadDockFromState(DockState state)
	{
		RadDock dock = new RadDock();
		dock.DockMode = DockMode.Docked;
		dock.ID = string.Format("RadDock{0}", state.UniqueName);
		dock.ApplyState(state);
		dock.Commands.Add(new DockCloseCommand());
		dock.Commands.Add(new DockExpandCollapseCommand());

		return dock;
	}

	private RadDock CreateRadDock()
	{
		int docksCount = CurrentDockStates.Count;

		RadDock dock = new RadDock();
		dock.DockMode = DockMode.Docked;
		dock.UniqueName = Guid.NewGuid().ToString().Replace("-", "a");
		dock.ID = string.Format("RadDock{0}", dock.UniqueName);
		dock.Title = "Dock";
		dock.Text = string.Format("Added at {0}", DateTime.Now);
		dock.Width = Unit.Pixel(300);

		dock.Commands.Add(new DockCloseCommand());
		dock.Commands.Add(new DockExpandCollapseCommand());

		return dock;
	}

	private void CreateSaveStateTrigger(RadDock dock)
	{
		//Ensure that the RadDock control will initiate postback
		// when its position changes on the client or any of the commands is clicked.
		//Using the trigger we will "ajaxify" that postback.
		dock.AutoPostBack = true;
		dock.CommandsAutoPostBack = true;

		AsyncPostBackTrigger saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "DockPositionChanged";
		UpdatePanel1.Triggers.Add(saveStateTrigger);

		saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "Command";
		UpdatePanel1.Triggers.Add(saveStateTrigger);
	}

	private void LoadWidget(RadDock dock)
	{
		if (string.IsNullOrEmpty(dock.Tag))
		{
			return;
		}
		HtmlGenericControl ctrl = new HtmlGenericControl("iframe");
		ctrl.Attributes.Add("src", ctrl.ResolveUrl(dock.Tag));
		ctrl.Style.Add(HtmlTextWriterStyle.Width, "300px");
		ctrl.Style.Add(HtmlTextWriterStyle.Height, "300px");

		dock.ContentContainer.Controls.Add(ctrl);
	}


	protected void ButtonAddDock_Click(object sender, EventArgs e)
	{
		RadDock dock = CreateRadDock();
		//find the target zone and add the new dock there
		RadDockZone dz = (RadDockZone)FindControl(DropDownZone.SelectedItem.Text);
		dz.Controls.Add(dock);
		CreateSaveStateTrigger(dock);

		//Load the selected widget in the RadDock control
		dock.Tag = DroptDownWidget.SelectedValue;
		LoadWidget(dock);
	}
	protected void ButtonPostBack_Click(object sender, EventArgs e)
	{
		//normal postback
	}
	protected void ButtonClear_Click(object sender, EventArgs e)
	{
		//clear docks state from the session
		CurrentDockStates.Clear();
		_dockStateCleared = true;
	}
}
